@@ -3,8 +3,6 @@ package yqlib
 import (
 	"container/list"
 	"fmt"
-
-	"gopkg.in/yaml.v3"
 )
 
 func isKeyOperator(d *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
@@ -30,7 +28,7 @@ func getKeyOperator(d *dataTreeNavigator, context Context, expressionNode *Expre
 		candidate := el.Value.(*CandidateNode)
 
 		if candidate.Key != nil {
-			results.PushBack(candidate.CreateReplacement(candidate.Key))
+			results.PushBack(candidate.Key)
 		}
 	}
 
@@ -45,41 +43,40 @@ func keysOperator(d *dataTreeNavigator, context Context, expressionNode *Express
 
 	for el := context.MatchingNodes.Front(); el != nil; el = el.Next() {
 		candidate := el.Value.(*CandidateNode)
-		node := unwrapDoc(candidate.Node)
-		var targetNode *yaml.Node
-		if node.Kind == yaml.MappingNode {
-			targetNode = getMapKeys(node)
-		} else if node.Kind == yaml.SequenceNode {
-			targetNode = getIndices(node)
+
+		var targetNode *CandidateNode
+		if candidate.Kind == MappingNode {
+			targetNode = getMapKeys(candidate)
+		} else if candidate.Kind == SequenceNode {
+			targetNode = getIndices(candidate)
 		} else {
-			return Context{}, fmt.Errorf("Cannot get keys of %v, keys only works for maps and arrays", node.Tag)
+			return Context{}, fmt.Errorf("Cannot get keys of %v, keys only works for maps and arrays", candidate.Tag)
 		}
 
-		result := candidate.CreateReplacement(targetNode)
-		results.PushBack(result)
+		results.PushBack(targetNode)
 	}
 
 	return context.ChildContext(results), nil
 }
 
-func getMapKeys(node *yaml.Node) *yaml.Node {
-	contents := make([]*yaml.Node, 0)
+func getMapKeys(node *CandidateNode) *CandidateNode {
+	contents := make([]*CandidateNode, 0)
 	for index := 0; index < len(node.Content); index = index + 2 {
 		contents = append(contents, node.Content[index])
 	}
-	return &yaml.Node{Kind: yaml.SequenceNode, Tag: "!!seq", Content: contents}
+	return &CandidateNode{Kind: SequenceNode, Tag: "!!seq", Content: contents}
 }
 
-func getIndices(node *yaml.Node) *yaml.Node {
-	var contents = make([]*yaml.Node, len(node.Content))
+func getIndices(node *CandidateNode) *CandidateNode {
+	var contents = make([]*CandidateNode, len(node.Content))
 
 	for index := range node.Content {
-		contents[index] = &yaml.Node{
-			Kind:  yaml.ScalarNode,
+		contents[index] = &CandidateNode{
+			Kind:  ScalarNode,
 			Tag:   "!!int",
 			Value: fmt.Sprintf("%v", index),
 		}
 	}
 
-	return &yaml.Node{Kind: yaml.SequenceNode, Tag: "!!seq", Content: contents}
+	return &CandidateNode{Kind: SequenceNode, Tag: "!!seq", Content: contents}
 }
