@@ -7,8 +7,6 @@ import (
 	"fmt"
 	"io"
 	"regexp"
-
-	yaml "gopkg.in/yaml.v3"
 )
 
 type Printer interface {
@@ -97,7 +95,7 @@ func (p *resultsPrinter) PrintedAnything() bool {
 	return p.printedMatches
 }
 
-func (p *resultsPrinter) printNode(node *yaml.Node, writer io.Writer) error {
+func (p *resultsPrinter) printNode(node *CandidateNode, writer io.Writer) error {
 	p.printedMatches = p.printedMatches || (node.Tag != "!!null" &&
 		(node.Tag != "!!bool" || node.Value != "false"))
 	return p.encoder.Encode(writer, node)
@@ -133,15 +131,15 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 
 	if p.firstTimePrinting {
 		node := matchingNodes.Front().Value.(*CandidateNode)
-		p.previousDocIndex = node.Document
-		p.previousFileIndex = node.FileIndex
+		p.previousDocIndex = node.GetDocument()
+		p.previousFileIndex = node.GetFileIndex()
 		p.firstTimePrinting = false
 	}
 
 	for el := matchingNodes.Front(); el != nil; el = el.Next() {
 
 		mappedDoc := el.Value.(*CandidateNode)
-		log.Debug("-- print sep logic: p.firstTimePrinting: %v, previousDocIndex: %v, mappedDoc.Document: %v", p.firstTimePrinting, p.previousDocIndex, mappedDoc.Document)
+		log.Debug("-- print sep logic: p.firstTimePrinting: %v, previousDocIndex: %v", p.firstTimePrinting, p.previousDocIndex)
 		log.Debug("%v", NodeToString(mappedDoc))
 		writer, errorWriting := p.printerWriter.GetWriter(mappedDoc)
 		if errorWriting != nil {
@@ -151,7 +149,7 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 		commentsStartWithSepExp := regexp.MustCompile(`^\$yqDocSeparator\$`)
 		commentStartsWithSeparator := commentsStartWithSepExp.MatchString(mappedDoc.LeadingContent)
 
-		if (p.previousDocIndex != mappedDoc.Document || p.previousFileIndex != mappedDoc.FileIndex) && !commentStartsWithSeparator {
+		if (p.previousDocIndex != mappedDoc.GetDocument() || p.previousFileIndex != mappedDoc.GetFileIndex()) && !commentStartsWithSeparator {
 			if err := p.encoder.PrintDocumentSeparator(writer); err != nil {
 				return err
 			}
@@ -167,11 +165,7 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 			return err
 		}
 
-		if err := p.printNode(mappedDoc.Node, destination); err != nil {
-			return err
-		}
-
-		if err := p.encoder.PrintLeadingContent(destination, mappedDoc.TrailingContent); err != nil {
+		if err := p.printNode(mappedDoc, destination); err != nil {
 			return err
 		}
 
@@ -191,7 +185,7 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 			}
 		}
 
-		p.previousDocIndex = mappedDoc.Document
+		p.previousDocIndex = mappedDoc.GetDocument()
 		if err := writer.Flush(); err != nil {
 			return err
 		}
